# $Id: common.pre,v 1.16 2015-03-31 12:24:37 pc161604 Exp $
# Copyright (c) 2006, 2020, Oracle and/or its affiliates.
# Common message file for Secure Global Desktop installation.

# Do we have gettext?  If not, use a monolingual substitute.
_N="" _C=""
if echo -n | grep n > /dev/null; then
_C="c"
else
_N="-n"
fi

SGD_GETTEXT=''
for _dir in `echo "$PATH" | tr : ' '`; do
case "${_dir}" in
/*) [ -x "${_dir}/gettext" ] && { SGD_GETTEXT="${_dir}/gettext"; break; }
esac
done
[ -z "${SGD_GETTEXT}" ] && SGD_GETTEXT='monolingual_gettext'

monolingual_gettext() {
case "$1" in -n) shift ;; esac
echo $_N "$*$_C"
}

# Find the message files: they will be in different places depending what stage
# of the installation we are at.
TEXTDOMAIN="SGD" TEXTDOMAINDIR="" export TEXTDOMAIN TEXTDOMAINDIR
[ -n "${INSTDIR}" ] && {
# We have an INSTDIR, so we should be able to find the locale files in their installed location.
locdir="${INSTDIR}/etc/locale"
[ -n "`find "${locdir}" -name ${TEXTDOMAIN}.mo -print 2>/dev/null`" ] && TEXTDOMAINDIR="${locdir}" export TEXTDOMAINDIR
}
[ -z "${TEXTDOMAINDIR}" -a -n "${REQDIR}" ] && {
# It looks as if we are in a pkgadd installation script.  Get the locale tar file from the
# installation work tree, and untar it into a location where we can access the locale info.
locdir="${REQDIR}/../reloc/etc/locale"
if [ -s "${locdir}.tar" -a -n "`find ${locdir} -name ${TEXTDOMAIN}.mo -print 2>/dev/null`" ]; then
# Set TTA_LOCALETMPDIR to a suitable location for untarring the locale bundle.
TTA_LOCALETMPDIR="/tmp/tta_localetmpdir/locale"
for tmpdir in "${TTA_TMPDIR}" "${TMPDIR}"; do
[ -n "${tmpdir}" -a -d "${tmpdir}" -a -w "${tmpdir}" ] && { TTA_LOCALETMPDIR="${tmpdir}/locale"; break; }
done
# Check to see if we have already untarred.
if [ ! -d "${TTA_LOCALETMPDIR}" ]; then
parentdir=`dirname ${TTA_LOCALETMPDIR}`
mkdir -p "${parentdir}" 2>/dev/null
[ -d "${parentdir}" -a -w "${parentdir}" ] && ( cd "${parentdir}"; cp "${locdir}.tar" . && tar xf locale.tar )
fi
[ -d "${TTA_LOCALETMPDIR}" -a -f "${TTA_LOCALETMPDIR}.tar" ] && TEXTDOMAINDIR="${TTA_LOCALETMPDIR}" export TEXTDOMAINDIR
fi
}
[ -z "${TEXTDOMAINDIR}" -a -n "${INST_DATADIR}" ] && {
TEXTDOMAINDIR="${INST_DATADIR}/${PKG}/reloc/\$INSTDIR/etc/locale" export TEXTDOMAINDIR
}

i18n_languagecode=`${SGD_GETTEXT} "en"`

i18n_yes=`${SGD_GETTEXT} "y"`
i18n_Y=`${SGD_GETTEXT} "Y"`
i18n_case_yes=`${SGD_GETTEXT} "yY"`
i18n_s_yes=`${SGD_GETTEXT} "yes"`

i18n_no=`${SGD_GETTEXT} "n"`
i18n_N=`${SGD_GETTEXT} "N"`
i18n_case_no=`${SGD_GETTEXT} "nN"`
i18n_s_no=`${SGD_GETTEXT} "no"`

i18n_quit=`${SGD_GETTEXT} "q"`
i18n_Q=`${SGD_GETTEXT} "Q"`
i18n_case_quit=`${SGD_GETTEXT} "qQ"`
i18n_s_quit=`${SGD_GETTEXT} "quit"`

i18n_recordingsettings=`${SGD_GETTEXT} "%s Setup is recording settings..."`
i18n_recordingsettings=`printf "${i18n_recordingsettings}" "${PRODUCT_SHORT_NAME}"`

i18n_stopping=`${SGD_GETTEXT} "Stopping %s server, please wait..."`
i18n_stopping=`printf "${i18n_stopping}" "${PRODUCT_SHORT_NAME}"`
i18n_secenable=`${SGD_GETTEXT} "
Enabling secure mode, please wait..."`

i18n_pf1_stoppingfrom=`${SGD_GETTEXT} "
Stopping %s server from %%s, please wait..."`
i18n_pf1_stoppingfrom=`printf "${i18n_pf1_stoppingfrom}" "${PRODUCT_SHORT_NAME}"`"
"

i18n_stopok=`${SGD_GETTEXT} "%s server stopped."`
i18n_stopok=`printf "${i18n_stopok}" "${PRODUCT_SHORT_NAME}"`

i18n_nostop=`${SGD_GETTEXT} "Unable to stop %s processes: Setup will continue
but may encounter problems. It may be necessary to remove the existing
%s installation."`
i18n_nostop=`printf "${i18n_nostop}" "${PRODUCT_SHORT_NAME}" "${PRODUCT_SHORT_NAME}"`

i18n_nostopuninstall=`${SGD_GETTEXT} "Unable to stop %s processes: uninstall will continue
but may encounter problems. It may be necessary to kill
%s processes manually."`
i18n_nostopuninstall=`printf "${i18n_nostopuninstall}" "${PRODUCT_SHORT_NAME}" "${PRODUCT_SHORT_NAME}"`

i18n_arrayuninstall=`${SGD_GETTEXT} "** Warning ** You should detach this server from the array before uninstalling.
You may continue with the uninstall if you wish, but the remaining array may
no longer function correctly if you do so."`

i18n_pf1_nostoplocation=`${SGD_GETTEXT} "The existing installation is located in %s"`"
"

i18n_nostart=`${SGD_GETTEXT} "Unable to start %s server: Setup will continue
but may encounter problems. It may be necessary to configure the
%s X Protocol Engine font path by hand."`
i18n_nostart=`printf "${i18n_nostart}" "${PRODUCT_SHORT_NAME}" "${PRODUCT_SHORT_NAME}"`

i18n_installing=`${SGD_GETTEXT} "%s Setup is installing files..."`
i18n_installing=`printf "${i18n_installing}" "${PRODUCT_SHORT_NAME}"`

i18n_pf1_removingoldpkg=`${SGD_GETTEXT} "Removing old files from previous %s installations..."`

i18n_oldwebserverconfig=`${SGD_GETTEXT} "Webserver configuration"`"
"
i18n_pf2_oldwebserverconfig=`${SGD_GETTEXT} "One or more configuration files from your previous webserver installation
have been saved in:
%s
If you made any local configuration changes that you want to preserve,
you will have to copy your changes to the appropriate place(s) in the new
webserver installation:
%s"`

i18n_configuring=`${SGD_GETTEXT} "Configuring your installation..."`

i18n_pf1_instsuccess=`${SGD_GETTEXT} "Successfully installed %s"`"
"

i18n_pf1_runningscript=`${SGD_GETTEXT} "Running %s Setup script..."`
i18n_scriptok=`${SGD_GETTEXT} "OK"`
i18n_pf1_scriptfail=`${SGD_GETTEXT} "Failed. Exit code: %s"`"
"

i18n_no_ttaserv_user=`${SGD_GETTEXT} "** Error ** Required users (ttaserv and ttasys) are not correctly defined.
Setup will now exit.

You must create two user accounts before you can install %s.

 - The user names must be \"ttaserv\" and \"ttasys\".
 - Both must have their primary group set to \"ttaserv\".
 - You can use any UIDs and GID you want.
 - Both users must have a valid shell, for example /bin/sh.
 - Both users must have writeable home directories.
 - We recommend that you lock the user accounts (passwd -l).

============================================================================
You can create the required users by running the /tmp/SGDCreateUsers.sh shell
script as root.  Before running the script, examine it and check that it will
create the users in a way that is consistent with your organization's usual
user management policies.  Please contact your network administrator if you
need help with this.
============================================================================"`
i18n_no_ttaserv_user=`printf "${i18n_no_ttaserv_user}" "${PRODUCT_SHORT_NAME}"`

i18n_setupusers_gw=`${SGD_GETTEXT} "** Error ** Required user/group (sgdgsys/sgdgserv) are not correctly defined.
Setup will now exit.

You must create the user and group before you can install %s.

 - The user name must be \"sgdgsys\".
 - The group name name must be \"sgdgserv\".
 - You can use any UIDs and GID you want.
 - The user must have a valid shell, for example /bin/sh.
 - The user must have a writeable home directory.
 - We recommend that you lock the user account (passwd -l).

============================================================================
You can create the required user and group by running the %s shell
script as root.  Before running the script, examine it and check that it will
create the user in a way that is consistent with your organization's usual
user management policies.  Please contact your network administrator if you
need help with this.
============================================================================"`

i18n_warnprefix=`${SGD_GETTEXT} "** Warning ** "`

i18n_archmismatch=`${SGD_GETTEXT} "Operating systems don't match.
The packages you're about to install are intended for a different operating
system. We recommend you exit Setup without installing the packages.
Continue installation only if you are sure the operating systems are
compatible."`

i18n_versionmismatch=`${SGD_GETTEXT} "Operating system version lower than expected.
The packages you're about to install are intended for a later revision
of your operating system. We recommend you exit Setup without installing
the packages. Continue installation only if you are sure the operating
systems are compatible."`

i18n_continue=`${SGD_GETTEXT} "Would you like Setup to continue?"`

i18n_upgrade=`${SGD_GETTEXT} "upgrade"`
i18n_reinstall=`${SGD_GETTEXT} "reinstall"`
i18n_install=`${SGD_GETTEXT} "install"`
i18n_modestd=`${SGD_GETTEXT} "standard"`
i18n_modessl=`${SGD_GETTEXT} "secure"`

i18n_cantupgrade=`${SGD_GETTEXT} "This %s server cannot be upgraded because it is not licensed
for upgrades. Check that you have added the correct license keys and try again.
Alternatively, you can uninstall your current installation and install the new
version as a clean install."`
i18n_cantupgrade=`printf "${i18n_cantupgrade}" "${PRODUCT_SHORT_NAME}"`

i18n_pf1_cantupgrade=`${SGD_GETTEXT} "%s does not support upgrades to this version (%s)
from version %%s. To attempt this upgrade at your own risk, create an
empty file called %%s and rerun the upgrade."`
i18n_pf1_cantupgrade=`${SGD_GETTEXT} "%s does not support upgrades to this version (%s)
from version %%s. To attempt this upgrade at your own risk, create an
empty file called %%s and rerun the upgrade."`
i18n_pf1_cantupgrade_gw=`printf "${i18n_pf1_cantupgrade}" "${GWCOMPONENT_NAME}" "${PRODUCT_VERSION_FULL}"`"
"

i18n_pf1_cantupgrade=`printf "${i18n_pf1_cantupgrade}" "${PRODUCT_SHORT_NAME}" "${PRODUCT_VERSION_FULL}"`"
"


i18n_forceupgrade=`${SGD_GETTEXT} "** Warning ** you have chosen to attempt an unsupported upgrade at your own risk."`

i18n_pf1_cantdowngrade=`${SGD_GETTEXT} "Sorry, but %s Setup can't downgrade to this version (%s) from version %%s."`
i18n_pf1_cantdowngrade=`printf "${i18n_pf1_cantdowngrade}" "${PRODUCT_SHORT_NAME}" "${PRODUCT_VERSION_FULL}"`"
"

i18n_licenseagreement=`${SGD_GETTEXT} "%s Software License Agreement"`
i18n_licenseagreement=`printf "${i18n_licenseagreement}" "${PRODUCT_SHORT_NAME}"`

i18n_chooselicop=`${SGD_GETTEXT} "To use %s you must agree to be bound by
the terms of the Software License Agreement.

  Y - I have read, and accept the terms of the license agreement
  N - I do not accept the terms of the license agreement
  R - Let me read the license agreement"`
i18n_chooselicop=`printf "${i18n_chooselicop}" "${PRODUCT_SHORT_NAME}"`

i18n_q_chooselicop=`${SGD_GETTEXT} "Accept terms of Software License Agreement?"`

i18n_readlicense=`${SGD_GETTEXT} "R"`
i18n_case_readlicense=`${SGD_GETTEXT} "rR"`

i18n_license=`${SGD_GETTEXT} "Have you read, and do you agree to the terms of the license?"`

i18n_docs=`${SGD_GETTEXT} "What's next?"`

i18n_docintro=`${SGD_GETTEXT} "%s is now installed and ready to use.

To get started:"`
i18n_docintro=`printf "${i18n_docintro}" "${PRODUCT_SHORT_NAME}"`"
"

i18n_pf1_url=`${SGD_GETTEXT} "
 - In a web browser, go to:
   %s"`

i18n_login_new=`${SGD_GETTEXT} "
 - When prompted, log in with username \"Administrator\" and the password of
   user \"%s\"."`

i18n_rolelogin_new=`${SGD_GETTEXT} "
 - The following Administration Role users have been added automatically:"`

i18n_login_upg=`${SGD_GETTEXT} "
 - When prompted, type the username and password for a %s
   Administrator."`
i18n_login_upg=`printf "${i18n_login_upg}" "${PRODUCT_SHORT_NAME}"`

i18n_webtop=`${SGD_GETTEXT} " - On your workspace, click the \"Help\" link to learn more about the product."`

i18n_pf1_readme_upgrade=`${SGD_GETTEXT} "
** Important ** Your installation has been upgraded. Please read
%s/var/log/upgraded.files
for details of modified files that have been preserved."`"
"

i18n_pf1_customizedfiles=`${SGD_GETTEXT} "
Setup upgraded a customized installation (version %%s).
This file contains details of how the customizations were preserved.

 - Number of files that were previously changed or added by hand
   in the original %s installation: "`
i18n_pf1_customizedfiles=`printf "${i18n_pf1_customizedfiles}" "${PRODUCT_SHORT_NAME}"`

i18n_pf2_customizedfiles1=`${SGD_GETTEXT} "
   See %s/var/log/customized.list.
   These customizations are preserved and still active within
   %s/var. You should review these files in conjunction with
   the upgrade information included in the Installation Guide."`"
"

i18n_pf1_customizedchanged=`${SGD_GETTEXT} "
 - Number of these files that would also change for the upgrade to
   %s %s: %%s"`
i18n_pf1_customizedchanged=`printf "${i18n_pf1_customizedchanged}" "${PRODUCT_SHORT_NAME}" "${PRODUCT_VERSION}"`"
"

i18n_pf4_customizedchanged1=`${SGD_GETTEXT} "
   See %s/var/log/customizedchanged.list.
   We recommend that you compare these files against the uncustomized
   template files used before and after the upgrade.
   Old templates: %s/etc/templates.%s
   New templates: %s/etc/templates"`"
"

i18n_pf3_expectupgrade=`${SGD_GETTEXT} "
Setup upgraded customized expect scripts from a previous
installation (version %s).

Your customizations to the following files have been saved in
%s/var/serverresources/expect.%s"`"
"

i18n_pf3_expectupgrade1=`${SGD_GETTEXT} "
We recommend that you compare these files against the uncustomized
template files and the newly installed files.

   New files:     %s/var/serverresources/expect
   Old templates: %s/etc/templates.%s/var/serverresources/expect"`"
"

i18n_pf1_docrootjava=`${SGD_GETTEXT} " - New or modified java files from the original installation
   have been detected and saved. For details see:
  %s"`"
"

i18n_readme_securid_upgrade=`${SGD_GETTEXT} "
** SecurID Upgrade ** Your SecurID configuration has been upgraded.
Your previous installation had SecurID Authentication Enabled.
During the upgrade process SecurID Authentication have been disabled,
You will need to reconfigure SecurID before re-enabling SecurID Authentication\n"`

i18n_pg_prompt=`${SGD_GETTEXT} "Press Return for next page..."`
i18n_less_prompt=`${SGD_GETTEXT} "Press Space for next page..."`

i18n_pf1_seesetuplog=`${SGD_GETTEXT} "Further details given in %s
may help to diagnose the problem."`"
"
i18n_nojre=`${SGD_GETTEXT} "Unable to find JRE in package or elsewhere on host"`

i18n_config_webservices=`${SGD_GETTEXT} "Configuring %s web server..."`
i18n_config_webservices=`printf "${i18n_config_webservices}" "${PRODUCT_SHORT_NAME}"`

i18n_check_mem_error=`${SGD_GETTEXT} "Not a valid memory value"`

i18n_stopping_message=`${SGD_GETTEXT} "Stopping Tier3 LoadProbe"`
i18n_running_message=`${SGD_GETTEXT} "The Tier3 LoadProbe is now running"`

i18n_install_t3=`${SGD_GETTEXT} "Installing files for %s"`
i18n_install_gw=`printf "${i18n_install_t3}" "${GWCOMPONENT_NAME}"`
i18n_install_t3=`printf "${i18n_install_t3}" "${T3COMPONENT_NAME}"`

i18n_pf2_oldver=`${SGD_GETTEXT} "You have the same or a newer version of this package installed:
  Old Version %s
  New Version %s"`"
"

i18n_pf1_already=`${SGD_GETTEXT} "
** Warning ** An existing version of this package is installed and will be removed.
The old version is %s"`"
"

i18n_pf1_instdir=`${SGD_GETTEXT} "Installation directory = %s"`"
"
i18n_vmem=`${SGD_GETTEXT} "How much virtual memory (Mb) does this server have?"`
i18n_q_vmem=`${SGD_GETTEXT} "Virtual memory (Mb)"`

i18n_unixaudio=`${SGD_GETTEXT} "Do you want to install the UNIX audio module?"`
i18n_unixaudio_unsupp=`${SGD_GETTEXT} "UNIX audio is a kernel module which is unsupported by your OS vendor.
Are you sure you want to install it?"`
i18n_h_unixaudio=`${SGD_GETTEXT} "Install UNIX audio?"`
i18n_unixaudio_nomake=`${SGD_GETTEXT} "Could not find make, please ensure it is in your PATH. UNIX audio module will not be available."`
i18n_unixaudio_nogcc=`${SGD_GETTEXT} "Could not find gcc, please ensure it is in your PATH. UNIX audio module will not be available."`
i18n_unixaudio_nosrc=`${SGD_GETTEXT} "Unable to locate kernel source tree"`
i18n_unixaudio_fail=`${SGD_GETTEXT} "Installation of UNIX audio failed."`
i18n_unixaudio_fail_desc=`${SGD_GETTEXT} "UNIX audio support can be installed later. To do this correct the above errors and execute 'make; make install' in '%s/audio/sgdadem/src', followed by '%s/bin/tem startaudio'. If this succeeds audio support will be enabled."`
i18n_unixaudio_fail_desc=`printf "${i18n_unixaudio_fail_desc}" "${INSTDIR}" "${INSTDIR}"`
i18n_unixaudio_cont=`${SGD_GETTEXT} "Do you want to continue without UNIX audio support?"`
i18n_unixaudio_success=`${SGD_GETTEXT} "UNIX audio module installed successfully"`
i18n_unixaudio_notremoved=`${SGD_GETTEXT} "UNIX audio driver 'sgdadem' is still in use. SGD audio services have been stopped and the driver will be removed on the next reboot."`
i18n_unixaudio_inuse=`${SGD_GETTEXT} "A previous SGD UNIX audio module is already loaded and being used by the kernel. The new UNIX audio driver cannot be loaded into the kernel while the old driver is in use."`
i18n_unixaudio_sada=`${SGD_GETTEXT} "Do you want to install the SADA audio module?"`
i18n_unixaudio_oss=`${SGD_GETTEXT} "Do you want to install the OSS audio module?"`
i18n_unixaudio_pulse=`${SGD_GETTEXT} "Do you want to install PulseAudio integration?"`
i18n_h_unixaudio_sada=`${SGD_GETTEXT} "Install SADA audio module?"`
i18n_h_unixaudio_oss=`${SGD_GETTEXT} "Install OSS audio module?"`
i18n_h_unixaudio_pulse=`${SGD_GETTEXT} "Install PulseAudio integration?"`

i18n_unixserio=`${SGD_GETTEXT} "Do you want to install the UNIX serial I/O module?"`
i18n_h_unixserio=`${SGD_GETTEXT} "Install UNIX serial I/O module?"`

i18n_cantfindvmstat=`${SGD_GETTEXT} "
** Warning ** Can't find prerequisite system program vmstat. You may continue
installation if you wish, but %s
will not work correctly until its prerequisites are installed."`
i18n_cantfindvmstat=`printf "${i18n_cantfindvmstat}" "${T3COMPONENT_NAME}"`

i18n_config_message=`${SGD_GETTEXT} "Finished configuration of %s"`
i18n_config_message=`printf "${i18n_config_message}" "${T3COMPONENT_NAME}"`

i18n_starting_message=`${SGD_GETTEXT} "Starting Tier3 LoadProbe"`

i18n_instdir=`${SGD_GETTEXT} "Installation directory"`
i18n_instdir_or_q=`${SGD_GETTEXT} "Installation directory (or Q to quit)"`
i18n_isafile=`${SGD_GETTEXT} "Sorry, but that's a file, not a directory. Please try again."`

i18n_badcertfile=`${SGD_GETTEXT} "Sorry, but that isn't a valid certificate file. Please try again."`
i18n_badkeyfile=`${SGD_GETTEXT} "Sorry, but that isn't a valid private key file. Please try again."`
i18n_certcheck4=`${SGD_GETTEXT} "Error: Invalid certificate file."`
i18n_certcheck7=`${SGD_GETTEXT} "Error: The supplied key and certificate do not match.
The key may belong to another certificate, or could be corrupt."`
i18n_certcheckca=`${SGD_GETTEXT} "Error: This root certificate does not match the certificate you supplied."`
i18n_certcheckerr=`${SGD_GETTEXT} "Error: Unable to validate certificate file."`

i18n_damage=`${SGD_GETTEXT} "Are these settings OK?
  Y - Yes, install using these settings
  N - No, tell me more about the options and let me change the settings
  Q - Quit now"`

i18n_q_damage=`${SGD_GETTEXT} "OK to use these settings?"`

i18n_nochange=`${SGD_GETTEXT} "%s Setup made no changes to your system."`
i18n_nochange_t3=`printf "${i18n_nochange}" "${T3COMPONENT_NAME}"`
i18n_nochange_gw=`printf "${i18n_nochange}" "${GWCOMPONENT_NAME}"`
i18n_nochange=`printf "${i18n_nochange}" "${PRODUCT_FULL_NAME}"`

i18n_h_instdir=`${SGD_GETTEXT} "%s installation directory"`
i18n_h_instdir_t3=`printf "${i18n_h_instdir}" "${T3COMPONENT_NAME}"`
i18n_h_instdir_gw=`printf "${i18n_h_instdir}" "${GWCOMPONENT_NAME}"`
i18n_h_instdir=`printf "${i18n_h_instdir}" "${PRODUCT_SHORT_NAME}"`

i18n_p_instdir=`${SGD_GETTEXT} "%s uses a single directory for all its code and other
static and dynamic components. Which directory would you like to use?"`
i18n_p_instdir_t3=`printf "${i18n_p_instdir}" "${T3COMPONENT_NAME}"`
i18n_p_instdir_gw=`printf "${i18n_p_instdir}" "${GWCOMPONENT_NAME}"`
i18n_p_instdir=`printf "${i18n_p_instdir}" "${PRODUCT_SHORT_NAME}"`

i18n_pf1_smbportnotavailable=`${SGD_GETTEXT} "** Warning ** Client drive mapping not available.
To support client drive mapping, a %s server component needs
to listen on TCP port %%s. Another program, for example Samba,
is currently using the port. This means the client drive mapping
functionality is not available.

To fix: stop the other program, and then restart %s server."`
i18n_pf1_smbportnotavailable=`printf "${i18n_pf1_smbportnotavailable}" "${PRODUCT_SHORT_NAME}" "${PRODUCT_SHORT_NAME}"`"
"

i18n_pf1_installtype=`${SGD_GETTEXT} "Installation type = %s"`"
"

i18n_q_instsecure=`${SGD_GETTEXT} "Install in secure mode?"`
i18n_h_instsecure=`${SGD_GETTEXT} "Install in secure mode"`
i18n_p_instsecure=`${SGD_GETTEXT} "
Would you like %s server to be installed
in secure mode?"`
i18n_p_instsecure=`printf "${i18n_p_instsecure}" "${PRODUCT_SHORT_NAME}"`

i18n_q_instsecurecert=`${SGD_GETTEXT} "Certificate file name"`
i18n_p_instsecurecert=`${SGD_GETTEXT} "
Full pathname of file containing certificate (or \"*\" if you want to use
a self-signed certificate)"`

i18n_q_instsecurekey=`${SGD_GETTEXT} "Private key file name"`
i18n_p_instsecurekey=`${SGD_GETTEXT} "
The specified certificate needs a private key.

Full pathname of file containing private key (or \"%s\" if you don't have
a private key file)"`
i18n_p_instsecurekey=`printf "${i18n_p_instsecurekey}" "${i18n_s_no}"`

i18n_q_instsecureroot=`${SGD_GETTEXT} "Root certificate file name"`
i18n_p_instsecureroot=`${SGD_GETTEXT} "
Full pathname of file containing root certificate (or \"%s\" if you don't have
a root certificate file)"`
i18n_p_instsecureroot=`printf "${i18n_p_instsecureroot}" "${i18n_s_no}"`

i18n_pf1_dupgrade=`${SGD_GETTEXT} "
** Warning ** a datastore has been detected in the installation directory,
 although the previous installation of %s has been removed.
 Setup will preserve it in directories with a %%s suffix.
 If you made any modifications that you want to preserve, you can copy
 these modifications manually after this installation has completed."`
i18n_pf1_dupgrade=`printf "${i18n_pf1_dupgrade}" "${PRODUCT_SHORT_NAME}"`"
"

i18n_unsupported_upgrade=`${SGD_GETTEXT} "
** Warning ** you are attempting an unsupported upgrade. You may continue
 at your own risk. Alternatively, quit this installation and uninstall
 your existing version before installing this version."`

i18n_instdir_insist=`${SGD_GETTEXT} "
If you really want to use the directory you have chosen, enter its name
followed by a \"!\" character."`

i18n_carryonregardless=`${SGD_GETTEXT} "... attempting installation anyway, by user request."`

i18n_badpeerdns=`${SGD_GETTEXT} "
The peer DNS name should be a fully-qualified domain name."`
i18n_peerdns_insist=`${SGD_GETTEXT} "
If you really want to use the name you have chosen, enter it again
followed by a \"!\" character."`

i18n_h_checkpoint=`${SGD_GETTEXT} "Archive logs every week"`
i18n_p_checkpoint=`${SGD_GETTEXT} "
Would you like %s server to archive its log files
every week?"`
i18n_p_checkpoint=`printf "${i18n_p_checkpoint}" "${PRODUCT_SHORT_NAME}"`

i18n_q_checkpoint=`${SGD_GETTEXT} "Archive logs every week?"`
i18n_p_checktime=`${SGD_GETTEXT} "
At what time should the archive occur?
Type a number between 0 (midnight) and 23 (11pm)."`"
"
i18n_q_checktime=`${SGD_GETTEXT} "Archive time"`
i18n_pf2_hours=`${SGD_GETTEXT} " (%s %02d:00 hours)"`
i18n_badnumber=`${SGD_GETTEXT} "Please type a number from 0 to 23, inclusive."`
i18n_p_checkday=`${SGD_GETTEXT} "
On what day should the archive occur?
Type a number between 0 (Sunday) and 6 (Saturday)."`"
"
i18n_q_checkday=`${SGD_GETTEXT} "Archive day"`
i18n_badday=`${SGD_GETTEXT} "Please type a number from 0 to 6, inclusive."`

i18n_sun=`${SGD_GETTEXT} "Sunday"`
i18n_mon=`${SGD_GETTEXT} "Monday"`
i18n_tue=`${SGD_GETTEXT} "Tuesday"`
i18n_wed=`${SGD_GETTEXT} "Wednesday"`
i18n_thu=`${SGD_GETTEXT} "Thursday"`
i18n_fri=`${SGD_GETTEXT} "Friday"`
i18n_sat=`${SGD_GETTEXT} "Saturday"`

i18n_h_restart=`${SGD_GETTEXT} "Start %s on reboot"`
i18n_h_restart=`printf "${i18n_h_restart}" "${PRODUCT_SHORT_NAME}"`

i18n_p_restart=`${SGD_GETTEXT} "Would you like %s server to start automatically
when the UNIX host reboots?"`
i18n_p_restart=`printf "${i18n_p_restart}" "${PRODUCT_SHORT_NAME}"`

i18n_q_restart=`${SGD_GETTEXT} "Start %s on reboot?"`
i18n_q_restart=`printf "${i18n_q_restart}" "${PRODUCT_SHORT_NAME}"`

i18n_p_runlevel=`${SGD_GETTEXT} "At which run level should %s server start?
Choose from:
  S - Single-user mode
  1 - Administration mode
  2 - Multi-user mode
  3 - Remote file-sharing mode
  4 - Alternative remote file-sharing mode"`
i18n_p_runlevel=`printf "${i18n_p_runlevel}" "${PRODUCT_SHORT_NAME}"`"
"

i18n_pf1_currun=`${SGD_GETTEXT} "Current run level is: %s"`
i18n_pf1_instrun=`${SGD_GETTEXT} "Currently installed at run level: %s"`
i18n_q_runlevel=`${SGD_GETTEXT} "Run level"`

i18n_h_peerdns=`${SGD_GETTEXT} "Peer (internal) DNS name"`

i18n_p_peerdns=`${SGD_GETTEXT} "Each computer on the network may have a number of DNS names.  In
%s, the peer DNS name is the name by which this host
is known to others within your firewall, if you have one. If you're
using an array of multiple %s servers, this is the
name used by other servers in the array to identify this server."`
i18n_p_peerdns=`printf "${i18n_p_peerdns}" "${PRODUCT_SHORT_NAME}" "${PRODUCT_SHORT_NAME}"`

i18n_q_peerdns=`${SGD_GETTEXT} "Peer DNS name"`

i18n_summary=`${SGD_GETTEXT} "Setting up %s"`
i18n_summary_t3=`printf "${i18n_summary}" "${T3COMPONENT_NAME}"`
i18n_summary_gw=`printf "${i18n_summary}" "${GWCOMPONENT_NAME}"`
i18n_summary=`printf "${i18n_summary}" "${PRODUCT_FULL_NAME}"`

i18n_recommend=`${SGD_GETTEXT} "%s Setup recommends you use the following settings:"`
i18n_recommend_t3=`printf "${i18n_recommend}" "${T3COMPONENT_NAME}"`
i18n_recommend=`printf "${i18n_recommend}" "${PRODUCT_SHORT_NAME}"`

i18n_recommend10_gw=`${SGD_GETTEXT} "%s Setup recommends you use the following
settings:"`
i18n_recommend10_gw=`printf "${i18n_recommend10_gw}" "${GWCOMPONENT_NAME}"`

i18n_pf1_instdircontents=`${SGD_GETTEXT} "
You are attempting to install %s in %%s,
which contains the following unexpected files:"`
i18n_pf1_instdircontents=`printf "${i18n_pf1_instdircontents}" "${PRODUCT_SHORT_NAME}"`"
"

i18n_httpport_inuse=`${SGD_GETTEXT} "
** Important ** The default %s port is in use. Either stop the process
that is using this port, or select a different port when prompted."`
i18n_httpport_inuse_https=`printf "${i18n_httpport_inuse}" "HTTPS"`
i18n_httpport_inuse=`printf "${i18n_httpport_inuse}" "HTTP"`

i18n_q_httpport=`${SGD_GETTEXT} "%s port"`
i18n_q_httpport_https=`printf "${i18n_q_httpport}" "HTTPS"`
i18n_q_httpport=`printf "${i18n_q_httpport}" "HTTP"`

i18n_pf1_httpportfree=`${SGD_GETTEXT} "%s port = %%s [not currently in use]"`"
"
i18n_pf1_httpportfree_https=`printf "${i18n_pf1_httpportfree}" "HTTPS"`"
"
i18n_pf1_httpportfree=`printf "${i18n_pf1_httpportfree}" "HTTP"`"
"

i18n_pf1_httpportinuse=`${SGD_GETTEXT} "%s port = %%s [already in use]"`"
"
i18n_pf1_httpportinuse_https=`printf "${i18n_pf1_httpportinuse}" "HTTPS"`"
"
i18n_pf1_httpportinuse=`printf "${i18n_pf1_httpportinuse}" "HTTP"`"
"

i18n_p_choosefreeport=`${SGD_GETTEXT} "You must choose an unused TCP port for installation to complete."`

i18n_p_httpport=`${SGD_GETTEXT} "%s includes a web server. You need to choose the TCP port
on which the web server listens for HTTP (unencrypted) connections.
The default port for HTTP is 80/tcp.
Note that even if you are installing in secure (HTTPS) mode, an HTTP port
is also required during installation."`"
"
i18n_p_httpport=`printf "${i18n_p_httpport}" "${PRODUCT_SHORT_NAME}"`"

${i18n_p_choosefreeport}"

i18n_p_httpsport=`${SGD_GETTEXT} "%s includes a web server. You need to choose the TCP port
on which the web server listens for HTTPS (encrypted) connections.
The default port for HTTPS is 443/tcp."`"
"
i18n_p_httpsport=`printf "${i18n_p_httpsport}" "${PRODUCT_SHORT_NAME}"`"

${i18n_p_choosefreeport}"

i18n_pf1_port=`${SGD_GETTEXT} "
Port %s is currently in use."`

i18n_pkguninst=`${SGD_GETTEXT} "
Setup will uninstall the following packages because their
functionality is included in the package you are installing:"`

i18n_pf1_start2configure=`${SGD_GETTEXT} "To complete the installation, please run %s/bin/tarantella start"`"
"

i18n_pf1_start2configure_t3=`${SGD_GETTEXT} "To complete the installation, please run %s/bin/tem start"`"
"

i18n_cupsconfig=`${SGD_GETTEXT} "
You have created a %s CUPS printer.  Ensure that CUPS
raw printing is enabled.  Depending on your version of CUPS, you may have
to edit mime.convs and mime.types files.  See CUPS documentation for details."`
i18n_cupsconfig=`printf "${i18n_cupsconfig}" "${PRODUCT_SHORT_NAME}"`"
"

i18n_pf2_adminfile=`${SGD_GETTEXT} "
Setup has created a pkgadd admin file (%s) which can be used
to direct pkgadd to ignore file conflicts.  To do that, quit this
installation now and re-run your pkgadd command as before, but with an
additional -a parameter specifying the admin file name:

  pkgadd -a %s -d <pkgfilename>

Would you like to quit now and restart the installation using the admin file?"`

i18n_pf2_q_adminfile=`${SGD_GETTEXT} "Enter %s (to quit and restart) or %s (to continue)"`
i18n_pf2_q_adminfile=`printf "${i18n_pf2_q_adminfile}" "${i18n_Y}" "${i18n_N}"`

i18n_starting10_gw=`${SGD_GETTEXT} "Starting %s"`
i18n_starting10_gw=`printf "${i18n_starting10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_stopping10_gw=`${SGD_GETTEXT} "Stopping %s"`
i18n_stopping10_gw=`printf "${i18n_stopping10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_cantstop10_gw=`${SGD_GETTEXT} "Failed to stop %s"`
i18n_cantstop10_gw=`printf "${i18n_cantstop10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_setup2configure01_gw=`${SGD_GETTEXT} ""`"
"
i18n_h_gatewayport10_gw=`${SGD_GETTEXT} "Interface and port for incoming %s connections"`
i18n_h_gatewayport10_gw=`printf "${i18n_h_gatewayport10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_p_gatewayport10_gw=`${SGD_GETTEXT} "Interface and port %s listens on for incoming proxy connections.
The default is Transmission Control Protocol (TCP) port 443, on all interfaces"`
i18n_p_gatewayport10_gw=`printf "${i18n_p_gatewayport10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_q_gatewayport_gw=`${SGD_GETTEXT} "What interface and port do you want to use for incoming proxy connections?"`
i18n_q_gatewayport_gw="${i18n_q_gatewayport_gw}
"
i18n_h_clientaddr10_gw=`${SGD_GETTEXT} "Hostname and port used by SGD clients
   to connect to %s"`
i18n_h_clientaddr10_gw=`printf "${i18n_h_clientaddr10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_p_clientaddr10_gw=`${SGD_GETTEXT} "Entry point for the network. This is the hostname and port that clients
use to connect to %s."`
i18n_p_clientaddr10_gw=`printf "${i18n_p_clientaddr10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_q_clientaddr10_gw=`${SGD_GETTEXT} "What hostname and port will clients use to connect to %s?"`
i18n_q_clientaddr10_gw=`printf "${i18n_q_clientaddr10_gw}" "${GWCOMPONENT_SHORTNAME}"`"
"
i18n_h_sgdsecure_gw=`${SGD_GETTEXT} "Use secure connections to your SGD server(s)?"`
i18n_p_sgdsecure10_gw=`${SGD_GETTEXT} "Format of outgoing traffic from %s to the SGD servers in
the array"`
i18n_p_sgdsecure10_gw=`printf "${i18n_p_sgdsecure10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_q_sgdsecure_gw=`${SGD_GETTEXT} "Do you want to use secure connections to the SGD server?"`

i18n_h_ipv6clients_gw=`${SGD_GETTEXT} "Disable IPv6 client connections?"`
i18n_p_ipv6clients_gw=`${SGD_GETTEXT} "%s now supports IPv6 traffic from clients and is enabled by default."`
i18n_p_ipv6clients_gw=`printf "${i18n_p_ipv6clients_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_q_ipv6clients_gw=`${SGD_GETTEXT} "Do you want to disable IPv6 connections to %s?"`
i18n_q_ipv6clients_gw=`printf "${i18n_q_ipv6clients_gw}" "${GWCOMPONENT_SHORTNAME}"`

i18n_badarg01_gw=`${SGD_GETTEXT} "Unknown argument %s"`"
"
i18n_invalidarg01_gw=`${SGD_GETTEXT} "Missing or invalid %s"`"
"
i18n_usage10_gw=`${SGD_GETTEXT} "Usage: gateway { start | stop | restart | config | server | status | version |
                 sslcert | sslkey | cert | clientcert | key | patch |
                 connection }

Operations on %s.  For help on subcommands, type (for example):

gateway start --help"`
i18n_usage10_gw=`printf "${i18n_usage10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_uninstallusage10_gw=`${SGD_GETTEXT} "Usage: gateway uninstall

Uninstall %s.
All Gateway settings and certificates will also be deleted,"`
i18n_uninstallusage10_gw=`printf "${i18n_uninstallusage10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_startusage10_gw=`${SGD_GETTEXT} "Usage: gateway start

Start %s"`
i18n_startusage10_gw=`printf "${i18n_startusage10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_statususage10_gw=`${SGD_GETTEXT} "Usage: gateway status
        [--xml|--delimiter <delimiter>]
        [--help|--all| [--server <server>]
                       [--client <client>]
                       [--type [HTTP|TCC|Websocket]]
                       [--time <start> <end>] ]

Show %s status"`
i18n_statususage10_gw=`printf "${i18n_statususage10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_statusmoreinfo_gw=`${SGD_GETTEXT} "More information on the current status is available if the reflection
service is enabled. This can be activated via

 gateway config enable --services-reflection-auth"`
i18n_statusmoreinfo_gw=`printf "${i18n_statusmoreinfo_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_statusstrange11_gw=`${SGD_GETTEXT} "%s status is inconsistent - consider running %%s/bin/gateway restart"`"
"
i18n_statusstrange11_gw=`printf "${i18n_statusstrange11_gw}" "${GWCOMPONENT_SHORTNAME}"`"
"
i18n_statusup10_gw=`${SGD_GETTEXT} "%s status: Running"`
i18n_statusup10_gw=`printf "${i18n_statusup10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_statusdown10_gw=`${SGD_GETTEXT} "%s status: Stopped"`
i18n_statusdown10_gw=`printf "${i18n_statusdown10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_stopusage10_gw=`${SGD_GETTEXT} "Usage: gateway stop [--force]

Stop %s

Options:
  --force  Stop unconditionally without asking any questions"`"
"
i18n_stopusage10_gw=`printf "${i18n_stopusage10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_restartusage10_gw=`${SGD_GETTEXT} "Usage: gateway restart [--force]

Restart %s

Options:
  --force  Restart unconditionally without asking any questions"`"
"
i18n_restartusage10_gw=`printf "${i18n_restartusage10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_configusage10_gw=`${SGD_GETTEXT} "Usage: gateway config { create | list | edit | enable | disable }

%s configuration.  For help on subcommands, type (for example):

gateway config create --help"`
i18n_configusage10_gw=`printf "${i18n_configusage10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_configcreateusage40_gw=`${SGD_GETTEXT} "Usage: gateway config create
          [ [--interface <interface>:<port>]
            [--entry-point <hostname>:<port>]
            [--out {plaintext|ssl}] ]

       gateway config create
          --file <config file>

Options:
  --interface   Interface and port %s listens on for incoming proxy
                connections. The default is TCP port 443, on all interfaces.
  --entry-point Entry point for the network. This is the hostname
                and port that clients use to connect to %s.
  --out         Format of outgoing traffic from %s to the SGD
                servers in the array. If you are using secure connections,
                choose ssl.
  --file        Specifies a file containing configuration settings.

Creates a new configuration for %s, overwriting the current
configuration"`
i18n_configcreateusage40_gw=`printf "${i18n_configcreateusage40_gw}" "${GWCOMPONENT_SHORTNAME}" "${GWCOMPONENT_SHORTNAME}" "${GWCOMPONENT_SHORTNAME}" "${GWCOMPONENT_SHORTNAME}"`
i18n_configlistusage10_gw=`${SGD_GETTEXT} "Usage: gateway config list
          [ --binding ]
          [ --routes-http-maxcon ]
          [ --routes-aip-maxcon ]
          [ --routes-reverseproxy-redirect ]
          [ --services-reflection-binding ]
          [ --services-reflection-auth-binding ]
          [ --services-clientcerts ]

Lists the current %s configuration.
If no command-line options are specified, the full configuration is listed.

Options:
  --binding
       Interface and port that the SGD Gateway listens on for incoming
       proxy connections.
  --routes-http-maxcon
       Maximum number of HTTP connections that can be serviced.
  --routes-aip-maxcon
       Maximum number of AIP connections that can be serviced.
  --routes-reverseproxy-redirect
       HTTP redirection port
  --services-reflection-binding
       Interface and port used for unauthenticated access to the SGD Gateway
       reflection service.
  --services-reflection-auth-binding
       Interface and port used for authenticated access to the SGD Gateway
       reflection service.
  --services-clientcerts
       Client authentication mode."`"
"
i18n_configlistusage10_gw=`printf "${i18n_configlistusage10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_configeditusage10_gw=`${SGD_GETTEXT} "Usage: gateway config edit
          [ --binding                          <value> ]
          [ --routes-http-maxcon               <value> ]
          [ --routes-aip-maxcon                <value> ]
          [ --routes-ws-maxcon                 <value> ]
          [ --routes-reverseproxy-redirect     <value> ]
          [ --services-reflection-binding      <value> ]
          [ --services-reflection-auth-binding <value> ]
          [ --services-clientcerts             <value> ]

Edits the current %s configuration.
At least one command-line option must be specified.

Options:
  --binding
       Interface and port that the SGD Gateway listens on for incoming
       proxy connections.
  --routes-http-maxcon
       Maximum number of HTTP connections that can be serviced.
  --routes-aip-maxcon
       Maximum number of AIP connections that can be serviced.
  --routes-ws-maxcon
       Maximum number of Websocket connections that can be serviced.
  --routes-reverseproxy-redirect
       HTTP redirection port
  --services-reflection-binding
       Interface and port used for unauthenticated access to the SGD Gateway
       reflection service.
  --services-reflection-auth-binding
       Interface and port used for authenticated access to the SGD Gateway
       reflection service.
   --services-clientcerts
       Client authentication mode (required|optional|disabled)."`"
"
i18n_configeditusage10_gw=`printf "${i18n_configeditusage10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_configenableusage10_gw=`${SGD_GETTEXT} "Usage: gateway config enable
          [ --services-reflection ]
          [ --services-reflection-auth ]
          [ --routes-http-redirect ]
          [ --ipv6 ]

Enables part of %s functionality.
At least one command-line option must be specified.

Options:
  --services-reflection
       Enables unauthenticated access to the SGD Gateway reflection service.
  --services-reflection-auth
       Enables authenticated access to the SGD Gateway reflection service.
  --routes-http-redirect
       Enables HTTP redirection to HTTPS.
  --ipv6
       Enables IPv6 client connections to the SGD Gateway."`"
"
i18n_configenableusage10_gw=`printf "${i18n_configenableusage10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_configdisableusage10_gw=`${SGD_GETTEXT} "Usage: gateway config disable
          [ --services-reflection ]
          [ --services-reflection-auth ]
          [ --routes-http-redirect ]
          [ --ipv6 ]

Disables part of %s functionality.
At least one command-line option must be specified.

Options:
  --services-reflection
       Disables unauthenticated access to the SGD Gateway reflection service.
  --services-reflection-auth
       Disables authenticated access to the SGD Gateway reflection service.
  --routes-http-redirect
       Disables HTTP redirection to HTTPS.
  --ipv6
       Disables IPv6 client connections to the SGD Gateway."`"
"
i18n_configdisableusage10_gw=`printf "${i18n_configdisableusage10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_serverusage10_gw=`${SGD_GETTEXT} "Usage: gateway server { add | add-array | remove | list | list-array }

%s server operations.  For help on subcommands, type (for example):

gateway server add --help"`
i18n_serverusage10_gw=`printf "${i18n_serverusage10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_serveraddusage10_gw=`${SGD_GETTEXT} "Usage: gateway server add
          --server <server name>
          --certfile <certificate file>
          --url <SGD web server URL>
          [--ssl-certfile <SSL certificate file>]

Options:
  --server        SGD server name
  --certfile      Peer certificate file for the specified SGD server
  --url           SGD web server URL
  --ssl-certfile  SSL certificate file for the specified SGD server

Adds details of an SGD server to %s configuration"`
i18n_serveraddusage10_gw=`printf "${i18n_serveraddusage10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_serverremoveusage10_gw=`${SGD_GETTEXT} "Usage: gateway server remove
          --server <server name>

Options:
  --server        SGD server name

Removes details of an SGD server from %s configuration"`
i18n_serverremoveusage10_gw=`printf "${i18n_serverremoveusage10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_serverlistusage10_gw=`${SGD_GETTEXT} "Usage: gateway server list

Shows certificate details and URLs for the SGD servers in the current
%s configuration"`
i18n_serverlistusage10_gw=`printf "${i18n_serverlistusage10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_keystorepassword_gw=`${SGD_GETTEXT} "Enter keystore password (characters will not be echoed): "`
i18n_keystorepasswordwrong_gw=`${SGD_GETTEXT} "Wrong keystore password: re-enter: "`
i18n_keystorepasswordtoomany_gw=`${SGD_GETTEXT} "Too many password attempts: exiting"`
i18n_needrestart10_gw=`${SGD_GETTEXT} "You will need to restart %s for this change to take effect"`
i18n_needrestart10_gw=`printf "${i18n_needrestart10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_confirmstop30_gw=`${SGD_GETTEXT} "** Warning ** All user and application sessions running through %s
will be disconnected and may be terminated. Application data can be lost
if %s is stopped unexpectedly.
Are you sure you want to stop %s?"`
i18n_confirmstop30_gw=`printf "${i18n_confirmstop30_gw}" "${GWCOMPONENT_SHORTNAME}" "${GWCOMPONENT_SHORTNAME}" "${GWCOMPONENT_SHORTNAME}"`
i18n_jarpstarted10_gw=`${SGD_GETTEXT} "%s started successfully"`
i18n_jarpstarted10_gw=`printf "${i18n_jarpstarted10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_jarpstatus11_gw=`${SGD_GETTEXT} "%s exit status %%s"`"
"
i18n_jarpstatus11_gw=`printf "${i18n_jarpstatus11_gw}" "${GWCOMPONENT_SHORTNAME}"`"
"
i18n_alreadyrunning12_gw=`${SGD_GETTEXT} "%s appears to be already running. If you want to restart it,
run \"gateway stop\" and try again. Alternatively, if you are sure it is
not already running, delete the files
%%s
and %%s and try again."`"
"
i18n_alreadyrunning12_gw=`printf "${i18n_alreadyrunning12_gw}" "${GWCOMPONENT_SHORTNAME}"`"
"
i18n_portinuse01_gw=`${SGD_GETTEXT} "   ** Warning ** port %s is in use"`"
"
i18n_interfaceandport_gw=`${SGD_GETTEXT} "Please enter a colon-separated interface and port number - eg *:443"`
i18n_needsgdsecure_gw=`${SGD_GETTEXT} "   ** Warning ** The SGD server must be running in secure mode, and SGD server
   SSL certificates will need to be provided when running \"gateway server add\"."`
i18n_certimportfailed01_gw=`${SGD_GETTEXT} "** Error ** failed to import certificate file (status %s)"`"
"
i18n_certexportfailed01_gw=`${SGD_GETTEXT} "** Error ** failed to export certificate file (status %s)"`"
"
i18n_chainfailed03_gw=`${SGD_GETTEXT} "** Error ** failed to chain files %s and %s (status %s)"`"
"
i18n_convfailed02_gw=`${SGD_GETTEXT} "** Error ** failed to convert file %s (status %s)"`"
"
i18n_keyimportfailed01_gw=`${SGD_GETTEXT} "** Error ** failed to import key file (status %s)"`"
"
i18n_keyexportfailed01_gw=`${SGD_GETTEXT} "** Error ** failed to export key file (status %s)"`"
"
i18n_printfailed01_gw=`${SGD_GETTEXT} "** Error ** failed to print certificate (status %s)"`"
"
i18n_deletefailed01_gw=`${SGD_GETTEXT} "** Error ** failed to delete certificate file (status %s)"`"
"
i18n_setupnext_gw=`${SGD_GETTEXT} "You should now:
1. Configure your SGD servers.
2. Start the SGD Gateway.
Refer to the SGD Gateway documentation for details."`
i18n_sslcertusage10_gw=`${SGD_GETTEXT} "Usage: gateway sslcert { export | print }

%s certificate management.  For help on subcommands, type (for example):

gateway sslcert export --help"`
i18n_sslcertusage10_gw=`printf "${i18n_sslcertusage10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_sslcertexportusage_gw=`${SGD_GETTEXT} "Usage: gateway sslcert export
          --certfile <certificate file>

Options:
  --certfile  Certificate file

This command exports the SGD Gateway's SSL certificate. The SGD Gateway's
SSL certificate is used to secure HTTP and AIP connections to the SGD Client."`
i18n_sslcertprintusage_gw=`${SGD_GETTEXT} "Usage: gateway sslcert print

This command displays the SGD Gateway's SSL certificate. The SGD Gateway's
SSL certificate is used to secure HTTP and AIP connections
to the SGD Client."`
i18n_sslkeyusage10_gw=`${SGD_GETTEXT} "Usage: gateway sslkey { import | export }

%s certificate management.  For help on subcommands, type (for example):

gateway sslkey export --help"`
i18n_sslkeyusage10_gw=`printf "${i18n_sslkeyusage10_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_sslkeyexportusage_gw=`${SGD_GETTEXT} "Usage: gateway sslkey export
          --keyfile <key file>
          [ --keypass <key password> ]

Options:
  --keyfile   Key file
  --keypass   Key password

This command exports the SGD Gateway's SSL private key. The SGD Gateway's
SSL private key is used in conjunction with the SGD Gateway's SSL certificate
to secure HTTP and AIP connections to the SGD Client."`
i18n_sslkeyimportusage_gw=`${SGD_GETTEXT} "Usage: gateway sslkey import
          --keyfile <key file>
          [ --keyalg [ RSA | DSA ] ]
          --certfile <certificate file>
          [ --cacertfile <CA certificate file> ]
          [ --alwaysoverwrite ]

Options:
  --keyfile          Key file in PEM format
  --keyalg           Key algorithm
  --certfile         Certificate file
  --cacertfile       CA Certificate file
  --alwaysoverwrite  Do not prompt before updating keystore

This command imports a private key, and its corresponding certificate,
to be used as the SGD Gateway's SSL private key. The SGD Gateway's SSL
private key is used in conjunction with the SGD Gateway's SSL certificate
to secure HTTP and AIP connections to the SGD Client."`
i18n_certexportusage_gw=`${SGD_GETTEXT} "Usage: gateway cert export
          --certfile <certificate file>

Options:
  --certfile  Certificate file

This command is used to export the SGD Gateway certificate. The SGD Gateway
certificate is used by the SGD server to encrypt routing tokens.

The exported SGD Gateway certificate should be installed onto your primary
SGD server in order to establish trust. This can be achieved by copying your
SGD Gateway certificate to your SGD server and executing the
\"tarantella gateway add\" command."`
i18n_keyimportusage_gw=`${SGD_GETTEXT} "Usage: gateway key import
          --keyfile <key file>
          [ --keyalg [ RSA | DSA ] ]
          --certfile <certificate file>
          [ --cacertfile <CA certificate file> ]
          [ --alwaysoverwrite ]

Options:
  --keyfile          Key file in PEM format
  --keyalg           Key algorithm
  --certfile         Certificate file
  --cacertfile       CA Certificate file
  --alwaysoverwrite  Do not prompt before updating keystore

This command imports a private key, and its corresponding certificate, to be
used as the SGD Gateway's private key. The SGD Gateway's private key is used
by the SGD Gateway to decrypt routing tokens.

It is important to note that the imported SGD Gateway certificate must also
be installed onto your primary SGD server in order to establish trust. This
can be achieved by transferring your SGD Gateway certificate to your SGD
server and executing the 'tarantella gateway add' command."`
i18n_heapwarn01_gw=`${SGD_GETTEXT} "** Warning ** The JVM has been configured to use %sMB of memory."`"
"
i18n_newheap01_gw=`${SGD_GETTEXT} "You have changed the maximum number of connections, resulting in a calculated
JVM memory requirement of %sMB."`"
"
i18n_newheapwarn01_gw=`${SGD_GETTEXT} "** Warning ** You have changed the maximum number of connections, resulting in
a calculated JVM memory requirement of %sMB."`"
"
i18n_heapbig_gw=`${SGD_GETTEXT} "This is more than 25% of the server's physical memory."`
i18n_heaphuge_gw=`${SGD_GETTEXT} "This may exceed the recommended limit and result in problems."`
i18n_referdoc_gw=`${SGD_GETTEXT} "Refer to SGD Gateway documentation if you want to change this setting."`
i18n_upgpreserved01_gw=`${SGD_GETTEXT} "
Files preserved from previous version (%s):"`"
"
i18n_upgavailable01_gw=`${SGD_GETTEXT} "
Files kept from previous version (%s), for possible manual integration
into current version:"`"
"
i18n_configchangeavail01_gw=`${SGD_GETTEXT} "
Config file re-created with new values.
Previous version kept as %s for possible manual integration.\n"`
i18n_keyexportsuccess_gw=`${SGD_GETTEXT} "
Key stored in file <%s>"`
i18n_clientcertusage1O_gw=`${SGD_GETTEXT} "Usage: gateway clientcert { import | list | remove }

%s client certificate operations.  For help on subcommands, type (for example):

gateway clientcert import --help"`
i18n_clientcertusage1O_gw=`printf "${i18n_clientcertusage1O_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_clientcertimportusage1O_gw=`${SGD_GETTEXT} "Usage: gateway clientcert import
          --alias <name>
          --certfile <certificate file>

Options:
  --alias         A unique alias name for the certificate.
  --certfile      Client certificate to add to the gateway's client certificate store.

Imports a client certificate into the gateway's client certificate store."`
i18n_clientcertlistusage1O_gw=`${SGD_GETTEXT} "Usage: gateway clientcert list

Lists the client certificates stored in the gateway's client certificate store."`
i18n_clientcertremoveusage1O_gw=`${SGD_GETTEXT} "Usage: gateway clientcert remove
          --alias <name>

Options:
  --alias         A unique alias name for the certificate.

Removes a client certificate from the gateway's client certificate store."`
i18n_waitforrefresh10_gw=`${SGD_GETTEXT} "This change will be automatically applied within one minute.\nA restart is not required."`
i18n_waitforrefresh10_gw=`printf "${i18n_waitforrefresh10_gw}"`
i18n_needtostartgw10_gw=`${SGD_GETTEXT} "This change will be applied when the gateway starts."`
i18n_needtostartgw10_gw=`printf "${i18n_needtostartgw10_gw}"`
i18n_serveraddarrayusage_gw=`${SGD_GETTEXT} "Usage: gateway server add-array
          --name <array name>
          --serverurl <SGD server URL>
          [--file <credentials file> | --token <token>]

Options:
  --name       A unique name for the SGD array.
  --serverurl  A URL for an SGD server in the array.
               All members of the array are added to the gateway.
               The URL is in the form http(s)://sgdserver[:port].
  --file       A file containing credentials for the SGD user used to
               authenticate on the SGD server.
  --token      A one-time token containing data for an SGD session used
               to authenticate on the SGD server.

If neither a file nor a token are supplied, the caller is prompted for
credentials.

Adds the details of the members of an SGD array to %s configuration."`
i18n_serveraddarrayusage_gw=`printf "${i18n_serveraddarrayusage_gw}" "${GWCOMPONENT_SHORTNAME}"`
i18n_serveraddarray_recv_info_gw=`${SGD_GETTEXT} "Received the array data from SGD ..."`
i18n_serveraddarray_error_remote_gw=`${SGD_GETTEXT} "Error: the SGD server reported a problem.

%s

Consult the logs for further information.
"`"
"
i18n_serveraddarray_error_gw=`${SGD_GETTEXT} "Error: unable to add the array.

Consult the logs for further information.
"`
i18n_serveraddarray_deploy_failed_gw=`${SGD_GETTEXT} "Unable to add the array."`
i18n_serveraddarray_exists_gw=`${SGD_GETTEXT} "The SGD server, %s, has already been added ..."`"
"
i18n_serveraddarray_removing_gw=`${SGD_GETTEXT} "Removing old data for the SGD server, %s ..."`"
"
i18n_serveraddarray_adding_gw=`${SGD_GETTEXT} "Adding the SGD server, %s ..."`"
"
i18n_serveraddarray_complete_gw=`${SGD_GETTEXT} "The array has been added."`
i18n_serveraddarray_error_missingserverurl_gw=`${SGD_GETTEXT} "Error: no serverurl provided."`
i18n_serveraddarray_error_invalidserverurl_gw=`${SGD_GETTEXT} "Error: invalid serverurl provided."`
i18n_serveraddarray_error_missingfile_gw=`${SGD_GETTEXT} "Error: no file provided."`
i18n_serveraddarray_error_invalidfile_gw=`${SGD_GETTEXT} "Error: invalid file provided."`
i18n_serveraddarray_cantcontactserver_gw=`${SGD_GETTEXT} "Error: unable to contact the SGD server."`
i18n_serveraddarray_error_missingname_gw=`${SGD_GETTEXT} "Error: no SGD array name provided."`
i18n_serveraddarray_error_missingtoken_gw=`${SGD_GETTEXT} "Error: no token provided."`
i18n_serveraddarray_error_tokenorfile_gw=`${SGD_GETTEXT} "Error: cannot provide both a file and a token."`
i18n_gatewaylistarray_shortusage_gw=`${SGD_GETTEXT} "Usage: gateway server list-array [--name <array name>]

  - List the SGD arrays added to this gateway using the \"gateway server add-array\" command
"`
i18n_gatewaylistarray_longusage_gw=`${SGD_GETTEXT} "Usage: gateway server list-array [--name <array name>]

Options:
  --name    The name of an SGD array.

Lists the SGD arrays added to this gateway via the \"gateway server add-array\" command.
An array listing consists of its name followed by its members.
All arrays are listed if \"--name\" is not provided.
"`
i18n_error_gatewaylistarray_no_arrays_configured=`${SGD_GETTEXT} "This Gateway has no arrays configured.
"`
i18n_error_gatewaylistarray_named_gateway_not_listed=`${SGD_GETTEXT} "Error: the array provided in --name has not been added to this Gateway.
"`
i18n_error_gatewaylistarray_no_name_given=`${SGD_GETTEXT} "Error: no array name provided.
"`

##########################################################################
# No i18n required from here on ...
#
l_running_ug_script="running upgrade script:"
l_ug_script_failed="...failed"
l_ug_script_ok="...success"
l_ug_script_inapplicable="...not applicable to this upgrade"
l_missing="Missing file: "
p_74="--------------------------------------------------------------------------
"
a_base_definstdir="/opt"
a_definstdir="/opt/tarantella"
a_definstdir2="/usr/tarantella"
lf_usage="<options>
where <options> are:
--instdir     Installation directory
--datadir     Data directory
--version     Current product version
--oldinstdir  Old installation directory
--olddatadir  Old data directory
--oldversion  Old version
--savefile    File containing shell variables"
# $Id: setup,v 1.32 2008-05-29 12:53:44 jm199791 Exp $
#  Copyright 2008 Sun Microsystems, Inc. All rights reserved.
# Strings specific to basepack Setup

####
# Install type
m_cantupgrade1="Sorry, but $PRODUCT_SHORT_NAME Setup can't "
m_cantupgrade2=" to this version ($PRODUCT_VERSION_FULL) from version "
m_cantupgrade3="."
m_upgrade_via330="Please upgrade first to version 3.30, and then you will be able to upgrade
from 3.30 to this version."

a_downgrade="downgrade"
a_upgrade="upgrade"

#####################
# Licensing bits
h_licenseagreement="$PRODUCT_SHORT_NAME Software License Agreement"
p_chooselicop="\
To use $PRODUCT_SHORT_NAME you must agree to be bound by
the terms of the Software License Agreement.

  Y - I have read, and accept the terms of the license agreement
  N - I do not accept the terms of the license agreement
  R - Let me read the license agreement"

q_chooselicop="Accept terms of Software License Agreement?"

# What you type to read the license agreement.
a_readlicense="R"
a_case_readlicense="rR"

# This is the question used once you've read the license agreement.
q_license="Have you read, and do you agree to the terms of the license?"

####
## Document root and cgi prompts
h_docs="What's next?"

p_docintro="\
$PRODUCT_SHORT_NAME is now installed and ready to use.

To get started:
"

# tta URL between 1 and 2; newline after 2.
p_url1="\
 - In a web browser, go to:
   "
p_url2=""

# Only one of these is shown: depends on new or upgrade install.
# Followed by newline.
p_login_new="\
 - When prompted, log in with username \"Administrator\" and root's password."
p_login_upg="\
 - When prompted, type the username and password for a $PRODUCT_SHORT_NAME
   Administrator."

p_webtop="\
 - On your webtop, click Administration Guide to learn more about the product.
"

p_license="\

To add license keys, type:
${INSTDIR}/bin/tarantella license add <key>...
"

p_readme_upgrade="
IMPORTANT: Your installation has been upgraded. Please read 
$INSTDIR/var/log/upgraded.files
for details of modified files that have been preserved.
"

p_customizedfiles1="\
Setup upgraded a customized installation (version "

p_customizedfiles1b=").
This file contains details of how the customizations were preserved.

 - Number of files that were previously changed or added by hand 
   in the original $PRODUCT_SHORT_NAME "

p_customizedfiles1c=" installation: "

p_customizedfiles2="
   See $INSTDIR/var/log/customized.list.
   These customizations are preserved and still active within
   $INSTDIR/var. You should review these files in conjunction with 
   $INSTDIR/var/docroot/help/en-us/base/gettingstarted/upgrading_tarantella.html"

p_customizedchanged1="
 - Number of these files that would also change for the upgrade to 
   $PRODUCT_SHORT_NAME $PRODUCT_VERSION: "

p_customizedchanged2="
   See $INSTDIR/var/log/customizedchanged.list.
   We recommend that you compare these files against the uncustomized
   template files used before and after the upgrade.
   Old templates: $INSTDIR/etc/templates."

p_customizedchanged2b="   New templates: $INSTDIR/etc/templates
"

p_expectupgrade1="\

Setup upgraded customized expect scripts from a previous 
installation (version "

# The code appends a build number to this string; the trailing dot is
# not punctuation, it's part of a filename.
p_expectupgrade1b=").

Your customizations to the following files have been saved in 
$INSTDIR/var/serverresources/expect."

# The code appends a build number to this string; the trailing dot is
# not punctuation, it's part of a filename.
p_expectupgrade2="\

   We recommend that you compare these files against the uncustomized
   template files and the newly installed files.
   New files:     $INSTDIR/var/serverresources/expect
   Old templates: $INSTDIR/etc/templates."

p_expectupgrade2b="/var/serverresources/expect
"

p_docrootjava=" - New or modified java files from the original installation
   have been detected and saved. For details see:
  "

pg_prompt="Press Return for next page..."
less_prompt="Press Space for next page..."

####
# certificates
p_copyingcerts="Copying existing X.509 certificates ..."
p_symlinkcantfind="Unable to resolve the certificates symlink:"
p_symlinkbadlink="The certificates symlink goes nowhere:"
p_nocertificate="Unable to find certificate:"

####
# Yes and No

a_case_y="yY"
a_case_yes="yY"
s_yes="yes"

a_case_n="nN"
a_case_no="nN"
s_no="no"

a_case_q="qQ"
a_case_quit="qQ"
s_quit="quit"

a_case_a="aA"

a_y="y"
a_n="n"
a_q="q"
a_a="a"

a_yes="yes"
a_no="no"
a_quit="quit"
a_auto="auto"

####
# Misc

l_seesetuplog1="Further details given in "
l_seesetuplog2="
may help to diagnose the problem."
m_nojre="Unable to find JRE in package or elsewhere on host"

###
# Web
l_config_webservices="$PRODUCT_SHORT_NAME web server..."

###
# Arch check
l_warnprefix="WARNING: "
l_archmismatch="Operating systems don't match.
The packages you're about to install are intended for a different operating
system. We recommend you exit Setup without installing the packages.
Continue installation only if you are sure the operating systems are
compatible."
l_versionmismatch="Operating system version lower than expected.
The packages you're about to install are intended for a later revision
of your operating system. We recommend you exit Setup without installing
the packages. Continue installation only if you are sure the operating
systems are compatible."
l_continue="Would you like Setup to continue?"
